@@ -1,15 +1,12 @@
 import datetime
-import secrets
 
 from sqlalchemy import Column, String, DateTime
 
 from uffd.database import db
-
-def random_token():
-	return secrets.token_hex(128)
+from uffd.utils import token_urlfriendly
 
 class Token():
-	token = Column(String(128), primary_key=True, default=random_token)
+	token = Column(String(128), primary_key=True, default=token_urlfriendly)
 	created = Column(DateTime, default=datetime.datetime.now)
 
 class PasswordToken(Token, db.Model):
